@@ -69,7 +69,7 @@ class Payment:
             # We will wait for max 5minutes for this tx to respond, if it does not, we will re-try
             if datetime.now() - start_time > timedelta(minutes=TIMEOUT_MINS):
                 success = False
-                logging.info(f"Transaction {self}, timed out!")
+                logging.info(f"Important: Transaction {self}, timed out!")
                 break
             try:
                 recepit = self.w3.eth.get_transaction_receipt(_hash)
@@ -82,13 +82,21 @@ class Payment:
                 # Sleep 10s while waiting
                 logging.info(f"Waiting for transaction '{self}' to finish (Nonce:{nonce})...")
                 sleep(10)
+            except ValueError as err:
+                if 'receipts not found by' in err.args[0]['message']:
+                    logging.info("Could not find TX, giving it a bit more time.")
+                    sleep(20)
+                else:
+                    logging.warning(f"Important: Error occurred trying to find recepit for transaction '{self}'.\n"
+                                    f"Error given: {err}.")
+                    return
 
         if success:
-            logging.info(f"Transaction {self} completed! _hash: {_hash} - "
+            logging.info(f"Important: Transaction {self} completed! _hash: {_hash} - "
                          f"Explorer: https://explorer.roninchain.com/tx/{str(_hash)}")
             return _hash
         else:
-            logging.info(f"Transaction {self} failed. Trying to augment gas price to unstuck it.")
+            logging.info(f"Important: Transaction {self} failed. Trying to augment gas price to unstuck it.")
             self.increase_gas_tx(nonce)
 
     def __str__(self):
@@ -147,6 +155,10 @@ class TrezorPayment:
             data=data,
             chain_id=2020
         )
+        l_sig = list(sig)
+        l_sig[1] = l_sig[1].lstrip(b'\x00')
+        l_sig[2] = l_sig[2].lstrip(b'\x00')
+        sig = tuple(l_sig)
         transaction = rlp.encode((nonce, self.w3.toWei(str(gas_price), 'gwei'), self.gas, to, 0, data) + sig)
         # Send raw transaction
         self.w3.eth.send_raw_transaction(transaction)
@@ -157,7 +169,7 @@ class TrezorPayment:
             # We will wait for max 5 minutes for this tx to respond, if it does not, we will re-try
             if datetime.now() - start_time > timedelta(minutes=TIMEOUT_MINS):
                 success = False
-                logging.info(f"Transaction {self}, timed out!")
+                logging.info(f"Important: Transaction {self}, timed out!")
                 break
             try:
                 recepit = self.w3.eth.get_transaction_receipt(_hash)
@@ -170,13 +182,21 @@ class TrezorPayment:
                 # Sleep 10s while waiting
                 logging.info(f"Waiting for transaction '{self}' to finish (Nonce:{nonce})...")
                 sleep(10)
+            except ValueError as err:
+                if 'receipts not found by' in err.args[0]['message']:
+                    logging.info("Could not find TX, giving it a bit more time.")
+                    sleep(20)
+                else:
+                    logging.warning(f"Important: Error occurred trying to find recepit for transaction '{self}'.\n"
+                                    f"Error given: {err}.")
+                    return
 
         if success:
-            logging.info(f"Transaction {self} completed! _hash: {_hash} - "
+            logging.info(f"Important: Transaction {self} completed! _hash: {_hash} - "
                          f"Explorer: https://explorer.roninchain.com/tx/{str(_hash)}")
             return _hash
         else:
-            logging.info(f"Transaction {self} failed. Trying to augment gas price to unstuck it.")
+            logging.info(f"Important: Transaction {self} failed. Trying to augment gas price to unstuck it.")
             self.increase_gas_tx(nonce)
 
     def __str__(self):
